@@ -2,7 +2,7 @@
  * This file is part of tiptop.
  *
  * Author: Erven ROHOU
- * Copyright (c) 2011, 2012, 2016 Inria
+ * Copyright (c) 2011, 2012, 2016, 2024 Inria
  *
  * License: GNU General Public License version 2.
  *
@@ -116,11 +116,15 @@ static int dump_options(FILE* out, struct option* opt)
 {
   if (fprintf(out, "%s\n", opt_sta) < 0)
     return -1;
+  if (dump_option_int(out, "batch", opt->batch) < 0)
+    return -1;
   if (dump_option_float(out, "cpu_threshold", opt->cpu_threshold ) < 0)
     return -1;
+  if  (dump_option_int(out, "debug", opt->debug) < 0)
+    return -1;
   if (dump_option_float(out, "delay", opt->delay ) < 0)
     return -1;
-  if (dump_option_string(out, "watch_name", opt->watch_name) < 0)
+  if  (dump_option_int(out, "idle", opt->idle) < 0)
     return -1;
   if (dump_option_int(out, "max_iter", opt->max_iter) < 0)
     return -1;
@@ -128,10 +132,28 @@ static int dump_options(FILE* out, struct option* opt)
     return -1;
   if (dump_option_int(out, "only_pid",(int) opt->only_pid) < 0)
     return -1;
-  if  (dump_option_int(out, "debug", opt->debug) < 0)
+  if (dump_option_int(out, "show_cmdline",(int) opt->show_cmdline) < 0)
     return -1;
-  if (dump_option_int(out, "batch", opt->batch) < 0)
+  if (dump_option_int(out, "show_epoch",(int) opt->show_epoch) < 0)
     return -1;
+  if (dump_option_int(out, "show_hypervisor",(int) opt->show_hv) < 0)
+    return -1;
+  if (dump_option_int(out, "show_kernel",(int) opt->show_kernel) < 0)
+    return -1;
+  if (dump_option_int(out, "show_timestamp",(int) opt->show_timestamp) < 0)
+    return -1;
+  if (dump_option_int(out, "show_threads",(int) opt->show_threads) < 0)
+    return -1;
+  if (dump_option_int(out, "show_user",(int) opt->show_user) < 0)
+    return -1;
+  if (dump_option_int(out, "sticky",(int) opt->sticky) < 0)
+    return -1;
+  if (dump_option_string(out, "watch_name", opt->watch_name) < 0)
+    return -1;
+  if (opt->watch_uid != -1) {
+    if (dump_option_int(out, "watch_uid", opt->watch_uid) < 0)
+      return -1;
+  }
   if (fprintf(out, "%s\n", opt_clo) < 0)
     return -1;
 
