@@ -2,7 +2,7 @@
  * This file is part of tiptop.
  *
  * Author: Antoine NAUDIN
- * Copyright (c) 2012, 2016 Inria
+ * Copyright (c) 2012, 2016, 2024 Inria
  *
  * License: GNU General Public License version 2.
  *
@@ -202,10 +202,10 @@ void show_error_win(WINDOW* win, int nb_proc)
   if (pos != maxy-2) { /* To complete screen */
     /* while (pos < maxy-2) */
     /*   mvwprintw(win, pos++, 1, "%s", blank); */
-    mvwprintw(win, pos, 1, "END", i);
+    mvwprintw(win, pos, 1, "END");
   }
   else
-    mvwprintw(win, pos, 1, ".....", i);
+    mvwprintw(win, pos, 1, ".....");
 
   /* restoring older state of tiptop.error */
   fseek(error_file, current_pos, SEEK_SET);
