@@ -2,7 +2,7 @@
  * This file is part of tiptop.
  *
  * Author: Erven ROHOU
- * Copyright (c) 2011, 2012, 2014, 2015, 2016, 2017 Inria
+ * Copyright (c) 2011, 2012, 2014-2017, 2023, 2024 Inria
  *
  * License: GNU General Public License version 2.
  *
@@ -80,7 +80,7 @@ struct process_list* init_proc_list()
 static void done_proc(struct process* const p)
 {
   int val_idx;
-  
+
   if (p->cmdline)
     free(p->cmdline);
   free(p->name);
@@ -132,7 +132,7 @@ static char* get_cmdline(int pid, char* result, int size)
 
   snprintf(name, sizeof(name) - 1, "/proc/%d/cmdline", pid);
   f = fopen(name, "r");
-  if (f) {    
+  if (f) {
     res = fgets(result, size, f);
     if (res && res[0]) {
       int j;
@@ -195,7 +195,7 @@ void start_counters(struct process* ptr,
     }
     num_files -= num_collected;
   }
-  
+
   for(zz = 0; zz < ptr->num_events; zz++)
     ptr->prev_values[zz] = 0;
 
@@ -260,9 +260,12 @@ void new_processes(struct process_list* const list,
 
   num_tids = list->num_tids;
 
+  events.size = sizeof(struct STRUCT_NAME);
   events.disabled = 0;
   events.pinned = 1;
-  events.exclude_hv = 1;
+  if (options->show_hv == 0) {
+    events.exclude_hv = 1;
+  }
   /* events.exclude_idle = 1; ?? */
   if (options->show_kernel == 0)
     events.exclude_kernel = 1;
@@ -405,13 +408,16 @@ void new_processes(struct process_list* const list,
           get_cmdline(pid, cmdline, sizeof(cmdline));
         ptr->cmdline = strdup(cmdline);
         ptr->name = strdup(proc_name);
-        ptr->timestamp.tv_sec = 0;
-        ptr->timestamp.tv_usec = 0;
+        struct timeval now;
+        gettimeofday(&now, NULL);
+        ptr->timestamp = now;
         ptr->prev_cpu_time_s = 0;
         ptr->prev_cpu_time_u = 0;
-        ptr->cpu_percent = 0.0;
-        ptr->cpu_percent_s = 0.0;
-        ptr->cpu_percent_u = 0.0;
+
+        /* initialize at 100 to avoid immediate collection as inactive */
+        ptr->cpu_percent =   100.0;
+        ptr->cpu_percent_s =   0.0;
+        ptr->cpu_percent_u = 100.0;
 
         float uptime;
         f = fopen("/proc/uptime", "r");
