@@ -2,7 +2,7 @@
  * This file is part of tiptop.
  *
  * Author: Erven ROHOU
- * Copyright (c) 2011, 2013, 2014 Inria
+ * Copyright (c) 2011, 2013, 2014, 2024 Inria
  *
  * License: GNU General Public License version 2.
  *
@@ -46,6 +46,7 @@ int check()
   }
   fclose(paranoid);
 
+  events.size = sizeof(struct STRUCT_NAME);
   events.disabled = 0;
   events.exclude_hv = 1;
   events.exclude_kernel = 1;
@@ -58,6 +59,12 @@ int check()
   flags = 0;
   pid = 0;   /* self */
   fd = perf_event_open(&events, pid, cpu, grp, flags);
+  if (fd == -1) {
+    /* Try a second time, not excluding hypervisor and kernel. */
+    events.exclude_hv = 0;
+    events.exclude_kernel = 0;
+    fd = perf_event_open(&events, pid, cpu, grp, flags);
+  }
   if (fd == -1) {
     perror("syscall");
     fprintf(stderr, "Could not perform syscall.\n");
@@ -70,12 +77,17 @@ int check()
       fprintf(stderr, "Linux 2.6.31+ is required, OS reports '%s'.\n",
               os.release);
     }
+    else if (paranoia_level == 3) {
+      fprintf(stderr, "Your kernel is set with an event paranoia value of 3\n");
+      fprintf(stderr, "Either run this program as root, or set a lower\n");
+      fprintf(stderr, "paranoia value at '%s'.\n", PARANOID2);
+    }
     else {
       fprintf(stderr, "Don't know why...\n");
     }
     exit(EXIT_FAILURE);
   }
-  
+
   close(fd);
   return paranoia_level;
 }
