@@ -2,7 +2,7 @@
  * This file is part of tiptop.
  *
  * Author: Erven ROHOU
- * Copyright (c) 2011, 2012 Inria
+ * Copyright (c) 2011, 2012, 2023, 2024 Inria
  *
  * License: GNU General Public License version 2.
  *
@@ -492,6 +492,29 @@ int add_column(screen_t* const s, char* header, char* format, char* desc,
 }
 
 
+/* Retrieve the maximum core ID from /proc/cpuinfo. Return -1 if file
+   does not exist, or no information is found.  */
+static int max_core_id()
+{
+  int num = -1;
+  FILE* f = fopen("/proc/cpuinfo", "r");
+  if (f) {
+    char line[100];
+    while (fgets(line, sizeof(line), f)) {
+      if (strncmp(line, "processor", 9) == 0) {
+        int val;
+        int res = sscanf(line, "%*s : %d", &val);
+        if ((res) && (val > num)) {
+          num = val;
+        }
+      }
+    }
+  fclose(f);
+  }
+  return num;
+}
+
+
 /* This is the default screen, it uses only target-independent
    counters defined in the Linux header file. */
 static screen_t* default_screen()
@@ -508,7 +531,25 @@ static screen_t* default_screen()
   /* add columns */
   add_column(s, " %CPU", "%5.1f", "Total CPU usage", "CPU_TOT");
   add_column(s, " %SYS", "%5.1f", "System CPU usage", "CPU_SYS");
-  add_column(s, "   P", " %3.0f", "Processor where last seen", "PROC_ID");
+  static int max_cpu = 0;
+  static int width_cpu = 1;
+  if (max_cpu == 0) {
+    /* first time here, compute the max core id */
+    max_cpu = max_core_id();
+    if (max_cpu == -1) {
+      max_cpu = 999; /* safe bet when retrieving the information failed? */
+    }
+    /* compute required number of digits */
+    while (max_cpu > 9) {
+      max_cpu /= 10;
+      width_cpu++;
+    }
+  }
+  char cpu_header[width_cpu+5];
+  snprintf(cpu_header, sizeof(cpu_header), "%*sP", width_cpu, "");
+  char cpu_fmt[10];  /* such as   %2.0f  */
+  snprintf(cpu_fmt, sizeof(cpu_fmt), " %%%d.0f", width_cpu);
+  add_column(s, cpu_header, cpu_fmt, "Processor where last seen", "PROC_ID");
   add_column(s, "  Mcycle", "%8.2f", "Cycles (millions)",
              "delta(CYCLE) / 1e6");
   add_column(s, "  Minstr", "%8.2f", "Instructions (millions)",
@@ -582,7 +623,7 @@ screen_t* get_screen_by_name(const char* name)
 
 
 char* gen_header(const screen_t* const s, const struct option* options,
-                 int width, int active_col)
+                 int width, int active_col, int pid_width)
 {
   char* hdr;
   char* ptr;
@@ -591,6 +632,8 @@ char* gen_header(const screen_t* const s, const struct option* options,
   const char high_on = '[';
   const char high_off = ']';
 
+  assert(pid_width >= 5);
+
   hdr = malloc(width);
   ptr = hdr;
 
@@ -607,11 +650,13 @@ char* gen_header(const screen_t* const s, const struct option* options,
   }
 
   if (options->show_user)
-    written = snprintf(ptr, width, " %cPID%c user      ",
+    written = snprintf(ptr, width, "%*s%cPID%c user      ",
+                       pid_width-5+1, " ",
                        active_col == -1 ? high_on : sep,
                        active_col == -1 ? high_off : sep);
   else
-    written = snprintf(ptr, width, " %cPID%c",
+    written = snprintf(ptr, width, "%*s%cPID%c",
+                       pid_width-5+1, " ",
                        active_col == -1 ? high_on : sep,
                        active_col == -1 ? high_off : sep);
 
